/*
*   GSAInputs  -- A container to hold the many inputs required to set up a genetic search.
*
*   Copyright (C) 1999-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Library General Public
*   License as published by the Free Software Foundation; either
*   version 2 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
**/
package jahuwaldt.tools.GeneticSearch;

import jahuwaldt.tools.math.EvaluatableNumOpt;


/**
*  This class serves as a container for all the many inputs required to
*  set up a genetic search.  Use this class to collect together the inputs
*  and then pass them to the GeneticSearch constructor all at once.
*
*  <p> Modified by:  Joseph A. Huwaldt    </p>
*
*  @author    Joseph A. Huwaldt    Date:  May 24, 1999
*  @version   June 21, 2002
**/
public class GSAInputs {

	// A reference to a class that contains a cost function and a penalty function
	// used to evaluate a given set of design variables.
	public EvaluatableNumOpt functions = null;

	// The number of organisms to include in the design search.
	public int populationSize = 50;

	// The number of bits to use for each design variable.
	public int[] bitsPerVariable = null;

	// The lower bounds (smallest value) for each design variable.
	public float[] lowerBounds = null;

	// The upper bounds (largest value) for each design variable.
	public float[] upperBounds = null;

	// A class that is used to generate whatever type of organism you want
	// to use to facilitate the genetic search.
	public OrganismFactory orgFactory = null;


}


