/*
*   OrganismFactory  -- Interface for all GA organism factories.
*
*   Copyright (C) 1999-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Library General Public
*   License as published by the Free Software Foundation; either
*   version 2 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
**/
package jahuwaldt.tools.GeneticSearch;



/**
*  Abstract factory interface that, when subclassed, can generate a specific type
*  of Organism for use in various types of genetic search algorithms.
*
*  <p> Modified by:  Joseph A. Huwaldt    </p>
*
*  @author    Joseph A. Huwaldt    Date:  May 24, 1999
*  @version   June 21, 2002
**/
public interface OrganismFactory {

	/**
	*  Returns a reference to a new organism of a specific type.
	*  Classes implementing this interface should create an
	*  organism of a specifc type.  Classes using this class can
	*  then be made independent of organism type.
	*
	*  @param  bitsPerVariable  Array identifying the number of bits per design variable
	*                           to be stored in this organism.
	*  @return  Returns a reference to a new organism of a specific type.
	**/
	Organism newOrganism( int[] bitsPerVariable );

}


